Class: Google::Apis::GmailV1::BatchModifyMessagesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BatchModifyMessagesRequest

Returns a new instance of BatchModifyMessagesRequest.



112
113
114
# File 'lib/google/apis/gmail_v1/classes.rb', line 112

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#add_classification_labelsArray<Google::Apis::GmailV1::ClassificationLabelValue>

A list of Classification Label values to add. If a Classification Label with the same label ID is already applied to the message, fields with existing field IDs will be updated and fields with new field IDs will be added. There's a limit of 20 Classification Label values per request. If the message is already classified and the final total number of Classification Label values exceeds the maximum allowed number of Classification Label values per message, the modification fails. Corresponds to the JSON property addClassificationLabels



90
91
92
# File 'lib/google/apis/gmail_v1/classes.rb', line 90

def add_classification_labels
  @add_classification_labels
end

#add_label_idsArray<String>

A list of label IDs to add to messages. Corresponds to the JSON property addLabelIds

Returns:

  • (Array<String>)


95
96
97
# File 'lib/google/apis/gmail_v1/classes.rb', line 95

def add_label_ids
  @add_label_ids
end

#idsArray<String>

The IDs of the messages to modify. There is a limit of 1000 ids per request. Corresponds to the JSON property ids

Returns:

  • (Array<String>)


100
101
102
# File 'lib/google/apis/gmail_v1/classes.rb', line 100

def ids
  @ids
end

#remove_classification_label_idsArray<String>

A list of Classification Label values to remove from messages. Corresponds to the JSON property removeClassificationLabelIds

Returns:

  • (Array<String>)


105
106
107
# File 'lib/google/apis/gmail_v1/classes.rb', line 105

def remove_classification_label_ids
  @remove_classification_label_ids
end

#remove_label_idsArray<String>

A list of label IDs to remove from messages. Corresponds to the JSON property removeLabelIds

Returns:

  • (Array<String>)


110
111
112
# File 'lib/google/apis/gmail_v1/classes.rb', line 110

def remove_label_ids
  @remove_label_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



117
118
119
120
121
122
123
# File 'lib/google/apis/gmail_v1/classes.rb', line 117

def update!(**args)
  @add_classification_labels = args[:add_classification_labels] if args.key?(:add_classification_labels)
  @add_label_ids = args[:add_label_ids] if args.key?(:add_label_ids)
  @ids = args[:ids] if args.key?(:ids)
  @remove_classification_label_ids = args[:remove_classification_label_ids] if args.key?(:remove_classification_label_ids)
  @remove_label_ids = args[:remove_label_ids] if args.key?(:remove_label_ids)
end