Class: Google::Apis::GmailV1::ClassificationLabelFieldValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb

Overview

Field values for a classification label.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClassificationLabelFieldValue

Returns a new instance of ClassificationLabelFieldValue.



143
144
145
# File 'lib/google/apis/gmail_v1/classes.rb', line 143

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#field_idString

Required. The field ID for the Classification Label Value. Maps to the ID field of the Google Drive Label.Field object. Corresponds to the JSON property fieldId

Returns:

  • (String)


134
135
136
# File 'lib/google/apis/gmail_v1/classes.rb', line 134

def field_id
  @field_id
end

#selectionString

Selection choice ID for the selection option. Should only be set if the field type is SELECTION in the Google Drive Label.Field object. Maps to the id field of the Google Drive Label.Field.SelectionOptions resource. Corresponds to the JSON property selection

Returns:

  • (String)


141
142
143
# File 'lib/google/apis/gmail_v1/classes.rb', line 141

def selection
  @selection
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



148
149
150
151
# File 'lib/google/apis/gmail_v1/classes.rb', line 148

def update!(**args)
  @field_id = args[:field_id] if args.key?(:field_id)
  @selection = args[:selection] if args.key?(:selection)
end