Class: Google::Apis::GmailV1::Delegate
- Inherits:
-
Object
- Object
- Google::Apis::GmailV1::Delegate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb
Overview
Settings for a delegate. Delegates can read, send, and delete messages, as well as view and add contacts, for the delegator's account. See "Set up mail delegation" for more information about delegates.
Instance Attribute Summary collapse
-
#delegate_email ⇒ String
The email address of the delegate.
-
#verification_status ⇒ String
Indicates whether this address has been verified and can act as a delegate for the account.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Delegate
constructor
A new instance of Delegate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Delegate
Returns a new instance of Delegate.
355 356 357 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 355 def initialize(**args) update!(**args) end |
Instance Attribute Details
#delegate_email ⇒ String
The email address of the delegate.
Corresponds to the JSON property delegateEmail
347 348 349 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 347 def delegate_email @delegate_email end |
#verification_status ⇒ String
Indicates whether this address has been verified and can act as a delegate for
the account. Read-only.
Corresponds to the JSON property verificationStatus
353 354 355 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 353 def verification_status @verification_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
360 361 362 363 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 360 def update!(**args) @delegate_email = args[:delegate_email] if args.key?(:delegate_email) @verification_status = args[:verification_status] if args.key?(:verification_status) end |