Class: Google::Apis::GmailV1::Filter
- Inherits:
-
Object
- Object
- Google::Apis::GmailV1::Filter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb
Overview
Resource definition for Gmail filters. Filters apply to specific messages instead of an entire email thread.
Instance Attribute Summary collapse
-
#action ⇒ Google::Apis::GmailV1::FilterAction
A set of actions to perform on a message.
-
#criteria ⇒ Google::Apis::GmailV1::FilterCriteria
Message matching criteria.
-
#id ⇒ String
The server assigned ID of the filter.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Filter
constructor
A new instance of Filter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Filter
Returns a new instance of Filter.
437 438 439 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 437 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ Google::Apis::GmailV1::FilterAction
A set of actions to perform on a message.
Corresponds to the JSON property action
425 426 427 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 425 def action @action end |
#criteria ⇒ Google::Apis::GmailV1::FilterCriteria
Message matching criteria.
Corresponds to the JSON property criteria
430 431 432 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 430 def criteria @criteria end |
#id ⇒ String
The server assigned ID of the filter.
Corresponds to the JSON property id
435 436 437 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 435 def id @id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
442 443 444 445 446 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 442 def update!(**args) @action = args[:action] if args.key?(:action) @criteria = args[:criteria] if args.key?(:criteria) @id = args[:id] if args.key?(:id) end |