Class: Google::Apis::GmailV1::ImapSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb

Overview

IMAP settings for an account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImapSettings

Returns a new instance of ImapSettings.



762
763
764
# File 'lib/google/apis/gmail_v1/classes.rb', line 762

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_expungeBoolean Also known as: auto_expunge?

If this value is true, Gmail will immediately expunge a message when it is marked as deleted in IMAP. Otherwise, Gmail will wait for an update from the client before expunging messages marked as deleted. Corresponds to the JSON property autoExpunge

Returns:

  • (Boolean)


740
741
742
# File 'lib/google/apis/gmail_v1/classes.rb', line 740

def auto_expunge
  @auto_expunge
end

#enabledBoolean Also known as: enabled?

Whether IMAP is enabled for the account. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


746
747
748
# File 'lib/google/apis/gmail_v1/classes.rb', line 746

def enabled
  @enabled
end

#expunge_behaviorString

The action that will be executed on a message when it is marked as deleted and expunged from the last visible IMAP folder. Corresponds to the JSON property expungeBehavior

Returns:

  • (String)


753
754
755
# File 'lib/google/apis/gmail_v1/classes.rb', line 753

def expunge_behavior
  @expunge_behavior
end

#max_folder_sizeFixnum

An optional limit on the number of messages that an IMAP folder may contain. Legal values are 0, 1000, 2000, 5000 or 10000. A value of zero is interpreted to mean that there is no limit. Corresponds to the JSON property maxFolderSize

Returns:

  • (Fixnum)


760
761
762
# File 'lib/google/apis/gmail_v1/classes.rb', line 760

def max_folder_size
  @max_folder_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



767
768
769
770
771
772
# File 'lib/google/apis/gmail_v1/classes.rb', line 767

def update!(**args)
  @auto_expunge = args[:auto_expunge] if args.key?(:auto_expunge)
  @enabled = args[:enabled] if args.key?(:enabled)
  @expunge_behavior = args[:expunge_behavior] if args.key?(:expunge_behavior)
  @max_folder_size = args[:max_folder_size] if args.key?(:max_folder_size)
end