Class: Google::Apis::GmailV1::KaclsKeyMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb

Overview

Metadata for private keys managed by an external key access control list service. For details about managing key access, see Google Workspace CSE API Reference.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KaclsKeyMetadata

Returns a new instance of KaclsKeyMetadata.



810
811
812
# File 'lib/google/apis/gmail_v1/classes.rb', line 810

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kacls_dataString

Opaque data generated and used by the key access control list service. Maximum size: 8 KiB. Corresponds to the JSON property kaclsData

Returns:

  • (String)


803
804
805
# File 'lib/google/apis/gmail_v1/classes.rb', line 803

def kacls_data
  @kacls_data
end

#kacls_uriString

The URI of the key access control list service that manages the private key. Corresponds to the JSON property kaclsUri

Returns:

  • (String)


808
809
810
# File 'lib/google/apis/gmail_v1/classes.rb', line 808

def kacls_uri
  @kacls_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



815
816
817
818
# File 'lib/google/apis/gmail_v1/classes.rb', line 815

def update!(**args)
  @kacls_data = args[:kacls_data] if args.key?(:kacls_data)
  @kacls_uri = args[:kacls_uri] if args.key?(:kacls_uri)
end