Class: Google::Apis::GmailV1::LanguageSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb

Overview

Language settings for an account. These settings correspond to the "Language settings" feature in the web interface.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LanguageSettings

Returns a new instance of LanguageSettings.



981
982
983
# File 'lib/google/apis/gmail_v1/classes.rb', line 981

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_languageString

The language to display Gmail in, formatted as an RFC 3066 Language Tag (for example en-GB, fr or ja for British English, French, or Japanese respectively). The set of languages supported by Gmail evolves over time, so please refer to the "Language" dropdown in the Gmail settings for all available options, as described in the language settings help article. For a table of sample values, see Manage language settings. Not all Gmail clients can display the same set of languages. In the case that a user's display language is not available for use on a particular client, said client automatically chooses to display in the closest supported variant (or a reasonable default). Corresponds to the JSON property displayLanguage

Returns:

  • (String)


979
980
981
# File 'lib/google/apis/gmail_v1/classes.rb', line 979

def display_language
  @display_language
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



986
987
988
# File 'lib/google/apis/gmail_v1/classes.rb', line 986

def update!(**args)
  @display_language = args[:display_language] if args.key?(:display_language)
end