Class: Google::Apis::GmailV1::ListDraftsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GmailV1::ListDraftsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb
Instance Attribute Summary collapse
-
#drafts ⇒ Array<Google::Apis::GmailV1::Draft>
List of drafts.
-
#next_page_token ⇒ String
Token to retrieve the next page of results in the list.
-
#result_size_estimate ⇒ Fixnum
Estimated total number of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListDraftsResponse
constructor
A new instance of ListDraftsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListDraftsResponse
Returns a new instance of ListDraftsResponse.
1065 1066 1067 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1065 def initialize(**args) update!(**args) end |
Instance Attribute Details
#drafts ⇒ Array<Google::Apis::GmailV1::Draft>
List of drafts. Note that the Message property in each Draft resource only
contains an id and a threadId. The messages.get method can
fetch additional message details.
Corresponds to the JSON property drafts
1053 1054 1055 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1053 def drafts @drafts end |
#next_page_token ⇒ String
Token to retrieve the next page of results in the list.
Corresponds to the JSON property nextPageToken
1058 1059 1060 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1058 def next_page_token @next_page_token end |
#result_size_estimate ⇒ Fixnum
Estimated total number of results.
Corresponds to the JSON property resultSizeEstimate
1063 1064 1065 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1063 def result_size_estimate @result_size_estimate end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1070 1071 1072 1073 1074 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1070 def update!(**args) @drafts = args[:drafts] if args.key?(:drafts) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result_size_estimate = args[:result_size_estimate] if args.key?(:result_size_estimate) end |