Class: Google::Apis::GmailV1::ListMessagesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMessagesResponse

Returns a new instance of ListMessagesResponse.



1210
1211
1212
# File 'lib/google/apis/gmail_v1/classes.rb', line 1210

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#messagesArray<Google::Apis::GmailV1::Message>

List of messages. Note that each message resource contains only an id and a threadId. Additional message details can be fetched using the messages.get method. Corresponds to the JSON property messages

Returns:



1198
1199
1200
# File 'lib/google/apis/gmail_v1/classes.rb', line 1198

def messages
  @messages
end

#next_page_tokenString

Token to retrieve the next page of results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1203
1204
1205
# File 'lib/google/apis/gmail_v1/classes.rb', line 1203

def next_page_token
  @next_page_token
end

#result_size_estimateFixnum

Estimated total number of results. Corresponds to the JSON property resultSizeEstimate

Returns:

  • (Fixnum)


1208
1209
1210
# File 'lib/google/apis/gmail_v1/classes.rb', line 1208

def result_size_estimate
  @result_size_estimate
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1215
1216
1217
1218
1219
# File 'lib/google/apis/gmail_v1/classes.rb', line 1215

def update!(**args)
  @messages = args[:messages] if args.key?(:messages)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result_size_estimate = args[:result_size_estimate] if args.key?(:result_size_estimate)
end