Class: Google::Apis::GmailV1::Message

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb

Overview

An email message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Message

Returns a new instance of Message.



1369
1370
1371
# File 'lib/google/apis/gmail_v1/classes.rb', line 1369

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#classification_label_valuesArray<Google::Apis::GmailV1::ClassificationLabelValue>

Classification Label values on the message. Available Classification Label schemas can be queried using the Google Drive Labels API. Each classification label ID must be unique. If duplicate IDs are provided, only one will be retained, and the selection is arbitrary. Only used for Google Workspace accounts. There's a limit of 20 Classification Label values per request. If the Classification Label values exceeds the maximum allowed number, the request fails. Corresponds to the JSON property classificationLabelValues



1309
1310
1311
# File 'lib/google/apis/gmail_v1/classes.rb', line 1309

def classification_label_values
  @classification_label_values
end

#history_idFixnum

The ID of the last history record that modified this message. Corresponds to the JSON property historyId

Returns:

  • (Fixnum)


1314
1315
1316
# File 'lib/google/apis/gmail_v1/classes.rb', line 1314

def history_id
  @history_id
end

#idString

The immutable ID of the message. Corresponds to the JSON property id

Returns:

  • (String)


1319
1320
1321
# File 'lib/google/apis/gmail_v1/classes.rb', line 1319

def id
  @id
end

#internal_dateFixnum

The internal message creation timestamp (epoch ms), which determines ordering in the inbox. For normal SMTP-received email, this represents the time the message was originally accepted by Google, which is more reliable than the Date header. However, for API-migrated mail, it can be configured by client to be based on the Date header. Corresponds to the JSON property internalDate

Returns:

  • (Fixnum)


1328
1329
1330
# File 'lib/google/apis/gmail_v1/classes.rb', line 1328

def internal_date
  @internal_date
end

#label_idsArray<String>

List of IDs of labels applied to this message. Corresponds to the JSON property labelIds

Returns:

  • (Array<String>)


1333
1334
1335
# File 'lib/google/apis/gmail_v1/classes.rb', line 1333

def label_ids
  @label_ids
end

#payloadGoogle::Apis::GmailV1::MessagePart

A single MIME message part. Corresponds to the JSON property payload



1338
1339
1340
# File 'lib/google/apis/gmail_v1/classes.rb', line 1338

def payload
  @payload
end

#rawString

The entire email message in an RFC 2822 formatted and base64url encoded string. Returned in messages.get and drafts.get responses when the format=RAW parameter is supplied. @required gmail.users.drafts.create gmail.users.drafts. update Corresponds to the JSON property raw NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


1347
1348
1349
# File 'lib/google/apis/gmail_v1/classes.rb', line 1347

def raw
  @raw
end

#size_estimateFixnum

Estimated size in bytes of the message. Corresponds to the JSON property sizeEstimate

Returns:

  • (Fixnum)


1352
1353
1354
# File 'lib/google/apis/gmail_v1/classes.rb', line 1352

def size_estimate
  @size_estimate
end

#snippetString

A short part of the message text. Corresponds to the JSON property snippet

Returns:

  • (String)


1357
1358
1359
# File 'lib/google/apis/gmail_v1/classes.rb', line 1357

def snippet
  @snippet
end

#thread_idString

The ID of the thread the message belongs to. To add a message or draft to a thread, the following criteria must be met: 1. The requested threadId must be specified on the Message or Draft.Message you supply with your request.

  1. The References and In-Reply-To headers must be set in compliance with the RFC 2822 standard. 3. The Subject headers must match. Corresponds to the JSON property threadId

Returns:

  • (String)


1367
1368
1369
# File 'lib/google/apis/gmail_v1/classes.rb', line 1367

def thread_id
  @thread_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
# File 'lib/google/apis/gmail_v1/classes.rb', line 1374

def update!(**args)
  @classification_label_values = args[:classification_label_values] if args.key?(:classification_label_values)
  @history_id = args[:history_id] if args.key?(:history_id)
  @id = args[:id] if args.key?(:id)
  @internal_date = args[:internal_date] if args.key?(:internal_date)
  @label_ids = args[:label_ids] if args.key?(:label_ids)
  @payload = args[:payload] if args.key?(:payload)
  @raw = args[:raw] if args.key?(:raw)
  @size_estimate = args[:size_estimate] if args.key?(:size_estimate)
  @snippet = args[:snippet] if args.key?(:snippet)
  @thread_id = args[:thread_id] if args.key?(:thread_id)
end