Class: Google::Apis::GmailV1::SmimeInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb

Overview

An S/MIME email config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SmimeInfo

Returns a new instance of SmimeInfo.



1817
1818
1819
# File 'lib/google/apis/gmail_v1/classes.rb', line 1817

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encrypted_key_passwordString

Encrypted key password, when key is encrypted. Corresponds to the JSON property encryptedKeyPassword

Returns:

  • (String)


1777
1778
1779
# File 'lib/google/apis/gmail_v1/classes.rb', line 1777

def encrypted_key_password
  @encrypted_key_password
end

#expirationFixnum

When the certificate expires (in milliseconds since epoch). Corresponds to the JSON property expiration

Returns:

  • (Fixnum)


1782
1783
1784
# File 'lib/google/apis/gmail_v1/classes.rb', line 1782

def expiration
  @expiration
end

#idString

The immutable ID for the SmimeInfo. Corresponds to the JSON property id

Returns:

  • (String)


1787
1788
1789
# File 'lib/google/apis/gmail_v1/classes.rb', line 1787

def id
  @id
end

#is_defaultBoolean Also known as: is_default?

Whether this SmimeInfo is the default one for this user's send-as address. Corresponds to the JSON property isDefault

Returns:

  • (Boolean)


1792
1793
1794
# File 'lib/google/apis/gmail_v1/classes.rb', line 1792

def is_default
  @is_default
end

#issuer_cnString

The S/MIME certificate issuer's common name. Corresponds to the JSON property issuerCn

Returns:

  • (String)


1798
1799
1800
# File 'lib/google/apis/gmail_v1/classes.rb', line 1798

def issuer_cn
  @issuer_cn
end

#pemString

PEM formatted X509 concatenated certificate string (standard base64 encoding). Format used for returning key, which includes public key as well as certificate chain (not private key). Corresponds to the JSON property pem

Returns:

  • (String)


1805
1806
1807
# File 'lib/google/apis/gmail_v1/classes.rb', line 1805

def pem
  @pem
end

#pkcs12String

PKCS#12 format containing a single private/public key pair and certificate chain. This format is only accepted from client for creating a new SmimeInfo and is never returned, because the private key is not intended to be exported. PKCS#12 may be encrypted, in which case encryptedKeyPassword should be set appropriately. Corresponds to the JSON property pkcs12 NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


1815
1816
1817
# File 'lib/google/apis/gmail_v1/classes.rb', line 1815

def pkcs12
  @pkcs12
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/google/apis/gmail_v1/classes.rb', line 1822

def update!(**args)
  @encrypted_key_password = args[:encrypted_key_password] if args.key?(:encrypted_key_password)
  @expiration = args[:expiration] if args.key?(:expiration)
  @id = args[:id] if args.key?(:id)
  @is_default = args[:is_default] if args.key?(:is_default)
  @issuer_cn = args[:issuer_cn] if args.key?(:issuer_cn)
  @pem = args[:pem] if args.key?(:pem)
  @pkcs12 = args[:pkcs12] if args.key?(:pkcs12)
end