Class: Google::Apis::GmailV1::SmtpMsa

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb

Overview

Configuration for communication with an SMTP service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SmtpMsa

Returns a new instance of SmtpMsa.



1864
1865
1866
# File 'lib/google/apis/gmail_v1/classes.rb', line 1864

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hostString

The hostname of the SMTP service. Required. Corresponds to the JSON property host

Returns:

  • (String)


1837
1838
1839
# File 'lib/google/apis/gmail_v1/classes.rb', line 1837

def host
  @host
end

#passwordString

The password that will be used for authentication with the SMTP service. This is a write-only field that can be specified in requests to create or update SendAs settings; it is never populated in responses. Corresponds to the JSON property password

Returns:

  • (String)


1844
1845
1846
# File 'lib/google/apis/gmail_v1/classes.rb', line 1844

def password
  @password
end

#portFixnum

The port of the SMTP service. Required. Corresponds to the JSON property port

Returns:

  • (Fixnum)


1849
1850
1851
# File 'lib/google/apis/gmail_v1/classes.rb', line 1849

def port
  @port
end

#security_modeString

The protocol that will be used to secure communication with the SMTP service. Required. Corresponds to the JSON property securityMode

Returns:

  • (String)


1855
1856
1857
# File 'lib/google/apis/gmail_v1/classes.rb', line 1855

def security_mode
  @security_mode
end

#usernameString

The username that will be used for authentication with the SMTP service. This is a write-only field that can be specified in requests to create or update SendAs settings; it is never populated in responses. Corresponds to the JSON property username

Returns:

  • (String)


1862
1863
1864
# File 'lib/google/apis/gmail_v1/classes.rb', line 1862

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1869
1870
1871
1872
1873
1874
1875
# File 'lib/google/apis/gmail_v1/classes.rb', line 1869

def update!(**args)
  @host = args[:host] if args.key?(:host)
  @password = args[:password] if args.key?(:password)
  @port = args[:port] if args.key?(:port)
  @security_mode = args[:security_mode] if args.key?(:security_mode)
  @username = args[:username] if args.key?(:username)
end