Class: Google::Apis::GmailV1::VacationSettings
- Inherits:
-
Object
- Object
- Google::Apis::GmailV1::VacationSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb
Overview
Vacation auto-reply settings for an account. These settings correspond to the " Vacation responder" feature in the web interface.
Instance Attribute Summary collapse
-
#enable_auto_reply ⇒ Boolean
(also: #enable_auto_reply?)
Flag that controls whether Gmail automatically replies to messages.
-
#end_time ⇒ Fixnum
An optional end time for sending auto-replies (epoch ms).
-
#response_body_html ⇒ String
Response body in HTML format.
-
#response_body_plain_text ⇒ String
Response body in plain text format.
-
#response_subject ⇒ String
Optional text to prepend to the subject line in vacation responses.
-
#restrict_to_contacts ⇒ Boolean
(also: #restrict_to_contacts?)
Flag that determines whether responses are sent to recipients who are not in the user's list of contacts.
-
#restrict_to_domain ⇒ Boolean
(also: #restrict_to_domain?)
Flag that determines whether responses are sent to recipients who are outside of the user's domain.
-
#start_time ⇒ Fixnum
An optional start time for sending auto-replies (epoch ms).
Instance Method Summary collapse
-
#initialize(**args) ⇒ VacationSettings
constructor
A new instance of VacationSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VacationSettings
Returns a new instance of VacationSettings.
1980 1981 1982 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1980 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_auto_reply ⇒ Boolean Also known as: enable_auto_reply?
Flag that controls whether Gmail automatically replies to messages.
Corresponds to the JSON property enableAutoReply
1926 1927 1928 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1926 def enable_auto_reply @enable_auto_reply end |
#end_time ⇒ Fixnum
An optional end time for sending auto-replies (epoch ms). When this is
specified, Gmail will automatically reply only to messages that it receives
before the end time. If both startTime and endTime are specified,
startTime must precede endTime.
Corresponds to the JSON property endTime
1935 1936 1937 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1935 def end_time @end_time end |
#response_body_html ⇒ String
Response body in HTML format. Gmail will sanitize the HTML before storing it.
If both response_body_plain_text and response_body_html are specified,
response_body_html will be used.
Corresponds to the JSON property responseBodyHtml
1942 1943 1944 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1942 def response_body_html @response_body_html end |
#response_body_plain_text ⇒ String
Response body in plain text format. If both response_body_plain_text and
response_body_html are specified, response_body_html will be used.
Corresponds to the JSON property responseBodyPlainText
1948 1949 1950 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1948 def response_body_plain_text @response_body_plain_text end |
#response_subject ⇒ String
Optional text to prepend to the subject line in vacation responses. In order
to enable auto-replies, either the response subject or the response body must
be nonempty.
Corresponds to the JSON property responseSubject
1955 1956 1957 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1955 def response_subject @response_subject end |
#restrict_to_contacts ⇒ Boolean Also known as: restrict_to_contacts?
Flag that determines whether responses are sent to recipients who are not in
the user's list of contacts.
Corresponds to the JSON property restrictToContacts
1961 1962 1963 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1961 def restrict_to_contacts @restrict_to_contacts end |
#restrict_to_domain ⇒ Boolean Also known as: restrict_to_domain?
Flag that determines whether responses are sent to recipients who are outside
of the user's domain. This feature is only available for Google Workspace
users.
Corresponds to the JSON property restrictToDomain
1969 1970 1971 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1969 def restrict_to_domain @restrict_to_domain end |
#start_time ⇒ Fixnum
An optional start time for sending auto-replies (epoch ms). When this is
specified, Gmail will automatically reply only to messages that it receives
after the start time. If both startTime and endTime are specified,
startTime must precede endTime.
Corresponds to the JSON property startTime
1978 1979 1980 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1978 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1985 def update!(**args) @enable_auto_reply = args[:enable_auto_reply] if args.key?(:enable_auto_reply) @end_time = args[:end_time] if args.key?(:end_time) @response_body_html = args[:response_body_html] if args.key?(:response_body_html) @response_body_plain_text = args[:response_body_plain_text] if args.key?(:response_body_plain_text) @response_subject = args[:response_subject] if args.key?(:response_subject) @restrict_to_contacts = args[:restrict_to_contacts] if args.key?(:restrict_to_contacts) @restrict_to_domain = args[:restrict_to_domain] if args.key?(:restrict_to_domain) @start_time = args[:start_time] if args.key?(:start_time) end |