Class: Google::Apis::GmailV1::CseKeyPair
- Inherits:
-
Object
- Object
- Google::Apis::GmailV1::CseKeyPair
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb
Overview
A client-side encryption S/MIME key pair, which is comprised of a public key, its certificate chain, and metadata for its paired private key. Gmail uses the key pair to complete the following tasks: - Sign outgoing client-side encrypted messages. - Save and reopen drafts of client-side encrypted messages.
- Save and reopen sent messages. - Decrypt incoming or archived S/MIME
messages. For administrators managing identities and keypairs for users in
their organization, requests require authorization with a service account that
has domain-wide delegation authority to impersonate users with
the
https://www.googleapis.com/auth/gmail.settings.basicscope. For users managing their own identities and keypairs, requests require hardware key encryption turned on and configured.
Instance Attribute Summary collapse
-
#disable_time ⇒ String
Output only.
-
#enablement_state ⇒ String
Output only.
-
#key_pair_id ⇒ String
Output only.
-
#pem ⇒ String
Output only.
-
#pkcs7 ⇒ String
Input only.
-
#private_key_metadata ⇒ Array<Google::Apis::GmailV1::CsePrivateKeyMetadata>
Metadata for instances of this key pair's private key.
-
#subject_email_addresses ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CseKeyPair
constructor
A new instance of CseKeyPair.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CseKeyPair
Returns a new instance of CseKeyPair.
285 286 287 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 285 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disable_time ⇒ String
Output only. If a key pair is set to DISABLED, the time that the key pair's
state changed from ENABLED to DISABLED. This field is present only when
the key pair is in state DISABLED.
Corresponds to the JSON property disableTime
249 250 251 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 249 def disable_time @disable_time end |
#enablement_state ⇒ String
Output only. The current state of the key pair.
Corresponds to the JSON property enablementState
254 255 256 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 254 def enablement_state @enablement_state end |
#key_pair_id ⇒ String
Output only. The immutable ID for the client-side encryption S/MIME key pair.
Corresponds to the JSON property keyPairId
259 260 261 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 259 def key_pair_id @key_pair_id end |
#pem ⇒ String
Output only. The public key and its certificate chain, in PEM format.
Corresponds to the JSON property pem
265 266 267 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 265 def pem @pem end |
#pkcs7 ⇒ String
Input only. The public key and its certificate chain. The chain must be in
PKCS#7 format and use PEM encoding and
ASCII armor.
Corresponds to the JSON property pkcs7
272 273 274 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 272 def pkcs7 @pkcs7 end |
#private_key_metadata ⇒ Array<Google::Apis::GmailV1::CsePrivateKeyMetadata>
Metadata for instances of this key pair's private key.
Corresponds to the JSON property privateKeyMetadata
277 278 279 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 277 def @private_key_metadata end |
#subject_email_addresses ⇒ Array<String>
Output only. The email address identities that are specified on the leaf
certificate.
Corresponds to the JSON property subjectEmailAddresses
283 284 285 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 283 def subject_email_addresses @subject_email_addresses end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
290 291 292 293 294 295 296 297 298 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 290 def update!(**args) @disable_time = args[:disable_time] if args.key?(:disable_time) @enablement_state = args[:enablement_state] if args.key?(:enablement_state) @key_pair_id = args[:key_pair_id] if args.key?(:key_pair_id) @pem = args[:pem] if args.key?(:pem) @pkcs7 = args[:pkcs7] if args.key?(:pkcs7) @private_key_metadata = args[:private_key_metadata] if args.key?(:private_key_metadata) @subject_email_addresses = args[:subject_email_addresses] if args.key?(:subject_email_addresses) end |