Class: Google::Apis::GmailV1::CsePrivateKeyMetadata
- Inherits:
-
Object
- Object
- Google::Apis::GmailV1::CsePrivateKeyMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb
Overview
Metadata for a private key instance.
Instance Attribute Summary collapse
-
#hardware_key_metadata ⇒ Google::Apis::GmailV1::HardwareKeyMetadata
Metadata for hardware keys.
-
#kacls_key_metadata ⇒ Google::Apis::GmailV1::KaclsKeyMetadata
Metadata for private keys managed by an external key access control list service.
-
#private_key_metadata_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CsePrivateKeyMetadata
constructor
A new instance of CsePrivateKeyMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CsePrivateKeyMetadata
Returns a new instance of CsePrivateKeyMetadata.
326 327 328 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 326 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hardware_key_metadata ⇒ Google::Apis::GmailV1::HardwareKeyMetadata
Metadata for hardware keys. If hardware key encryption is set up for the Google Workspace organization,
users can optionally store their private key on their smart card and use it to
sign and decrypt email messages in Gmail by inserting their smart card into a
reader attached to their Windows device.
Corresponds to the JSON property hardwareKeyMetadata
312 313 314 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 312 def @hardware_key_metadata end |
#kacls_key_metadata ⇒ Google::Apis::GmailV1::KaclsKeyMetadata
Metadata for private keys managed by an external key access control list
service. For details about managing key access, see Google Workspace CSE API
Reference.
Corresponds to the JSON property kaclsKeyMetadata
319 320 321 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 319 def @kacls_key_metadata end |
#private_key_metadata_id ⇒ String
Output only. The immutable ID for the private key metadata instance.
Corresponds to the JSON property privateKeyMetadataId
324 325 326 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 324 def @private_key_metadata_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
331 332 333 334 335 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 331 def update!(**args) @hardware_key_metadata = args[:hardware_key_metadata] if args.key?(:hardware_key_metadata) @kacls_key_metadata = args[:kacls_key_metadata] if args.key?(:kacls_key_metadata) @private_key_metadata_id = args[:private_key_metadata_id] if args.key?(:private_key_metadata_id) end |