Class: Google::Apis::GmailV1::FilterAction
- Inherits:
-
Object
- Object
- Google::Apis::GmailV1::FilterAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb
Overview
A set of actions to perform on a message.
Instance Attribute Summary collapse
-
#add_label_ids ⇒ Array<String>
List of labels to add to the message.
-
#forward ⇒ String
Email address that the message should be forwarded to.
-
#remove_label_ids ⇒ Array<String>
List of labels to remove from the message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FilterAction
constructor
A new instance of FilterAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FilterAction
Returns a new instance of FilterAction.
470 471 472 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 470 def initialize(**args) update!(**args) end |
Instance Attribute Details
#add_label_ids ⇒ Array<String>
List of labels to add to the message.
Corresponds to the JSON property addLabelIds
456 457 458 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 456 def add_label_ids @add_label_ids end |
#forward ⇒ String
Email address that the message should be forwarded to. This effectively
redirects the message to the address specified in this field, maintaining the
original sender in the "From" field.
Corresponds to the JSON property forward
463 464 465 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 463 def forward @forward end |
#remove_label_ids ⇒ Array<String>
List of labels to remove from the message.
Corresponds to the JSON property removeLabelIds
468 469 470 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 468 def remove_label_ids @remove_label_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
475 476 477 478 479 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 475 def update!(**args) @add_label_ids = args[:add_label_ids] if args.key?(:add_label_ids) @forward = args[:forward] if args.key?(:forward) @remove_label_ids = args[:remove_label_ids] if args.key?(:remove_label_ids) end |