Class: Google::Apis::GmailV1::FilterAction
- Inherits:
-
Object
- Object
- Google::Apis::GmailV1::FilterAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb
Overview
A set of actions to perform on a message.
Instance Attribute Summary collapse
-
#add_label_ids ⇒ Array<String>
List of labels to add to the message.
-
#forward ⇒ String
Email address that the message should be forwarded to.
-
#remove_label_ids ⇒ Array<String>
List of labels to remove from the message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FilterAction
constructor
A new instance of FilterAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FilterAction
Returns a new instance of FilterAction.
452 453 454 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 452 def initialize(**args) update!(**args) end |
Instance Attribute Details
#add_label_ids ⇒ Array<String>
List of labels to add to the message.
Corresponds to the JSON property addLabelIds
438 439 440 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 438 def add_label_ids @add_label_ids end |
#forward ⇒ String
Email address that the message should be forwarded to. This effectively
redirects the message to the address specified in this field, maintaining the
original sender in the "From" field.
Corresponds to the JSON property forward
445 446 447 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 445 def forward @forward end |
#remove_label_ids ⇒ Array<String>
List of labels to remove from the message.
Corresponds to the JSON property removeLabelIds
450 451 452 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 450 def remove_label_ids @remove_label_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
457 458 459 460 461 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 457 def update!(**args) @add_label_ids = args[:add_label_ids] if args.key?(:add_label_ids) @forward = args[:forward] if args.key?(:forward) @remove_label_ids = args[:remove_label_ids] if args.key?(:remove_label_ids) end |