Class: Google::Apis::GmailV1::FilterCriteria
- Inherits:
-
Object
- Object
- Google::Apis::GmailV1::FilterCriteria
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb
Overview
Message matching criteria.
Instance Attribute Summary collapse
-
#exclude_chats ⇒ Boolean
(also: #exclude_chats?)
Whether the response should exclude chats.
-
#from ⇒ String
The sender's display name or email address.
-
#has_attachment ⇒ Boolean
(also: #has_attachment?)
Whether the message has any attachment.
-
#negated_query ⇒ String
Only return messages not matching the specified query.
-
#query ⇒ String
Only return messages matching the specified query.
-
#size ⇒ Fixnum
The size of the entire RFC822 message in bytes, including all headers and attachments.
-
#size_comparison ⇒ String
How the message size in bytes should be in relation to the size field.
-
#subject ⇒ String
Case-insensitive phrase found in the message's subject.
-
#to ⇒ String
The recipient's display name or email address.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FilterCriteria
constructor
A new instance of FilterCriteria.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FilterCriteria
Returns a new instance of FilterCriteria.
542 543 544 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 542 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exclude_chats ⇒ Boolean Also known as: exclude_chats?
Whether the response should exclude chats.
Corresponds to the JSON property excludeChats
489 490 491 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 489 def exclude_chats @exclude_chats end |
#from ⇒ String
The sender's display name or email address.
Corresponds to the JSON property from
495 496 497 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 495 def from @from end |
#has_attachment ⇒ Boolean Also known as: has_attachment?
Whether the message has any attachment.
Corresponds to the JSON property hasAttachment
500 501 502 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 500 def @has_attachment end |
#negated_query ⇒ String
Only return messages not matching the specified query. Supports the same query
format as the Gmail search box. For example, "from:someuser@example.com
rfc822msgid: is:unread".
Corresponds to the JSON property negatedQuery
508 509 510 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 508 def negated_query @negated_query end |
#query ⇒ String
Only return messages matching the specified query. Supports the same query
format as the Gmail search box. For example, "from:someuser@example.com
rfc822msgid: is:unread".
Corresponds to the JSON property query
515 516 517 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 515 def query @query end |
#size ⇒ Fixnum
The size of the entire RFC822 message in bytes, including all headers and
attachments.
Corresponds to the JSON property size
521 522 523 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 521 def size @size end |
#size_comparison ⇒ String
How the message size in bytes should be in relation to the size field.
Corresponds to the JSON property sizeComparison
526 527 528 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 526 def size_comparison @size_comparison end |
#subject ⇒ String
Case-insensitive phrase found in the message's subject. Trailing and leading
whitespace are be trimmed and adjacent spaces are collapsed.
Corresponds to the JSON property subject
532 533 534 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 532 def subject @subject end |
#to ⇒ String
The recipient's display name or email address. Includes recipients in the "to",
"cc", and "bcc" header fields. You can use simply the local part of the email
address. For example, "example" and "example@" both match "example@gmail.com".
This field is case-insensitive.
Corresponds to the JSON property to
540 541 542 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 540 def to @to end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
547 548 549 550 551 552 553 554 555 556 557 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 547 def update!(**args) @exclude_chats = args[:exclude_chats] if args.key?(:exclude_chats) @from = args[:from] if args.key?(:from) @has_attachment = args[:has_attachment] if args.key?(:has_attachment) @negated_query = args[:negated_query] if args.key?(:negated_query) @query = args[:query] if args.key?(:query) @size = args[:size] if args.key?(:size) @size_comparison = args[:size_comparison] if args.key?(:size_comparison) @subject = args[:subject] if args.key?(:subject) @to = args[:to] if args.key?(:to) end |