Class: Google::Apis::GmailV1::HardwareKeyMetadata
- Inherits:
-
Object
- Object
- Google::Apis::GmailV1::HardwareKeyMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb
Overview
Metadata for hardware keys. If hardware key encryption is set up for the Google Workspace organization, users can optionally store their private key on their smart card and use it to sign and decrypt email messages in Gmail by inserting their smart card into a reader attached to their Windows device.
Instance Attribute Summary collapse
-
#description ⇒ String
Description about the hardware key.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HardwareKeyMetadata
constructor
A new instance of HardwareKeyMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HardwareKeyMetadata
Returns a new instance of HardwareKeyMetadata.
581 582 583 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 581 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Description about the hardware key.
Corresponds to the JSON property description
579 580 581 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 579 def description @description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
586 587 588 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 586 def update!(**args) @description = args[:description] if args.key?(:description) end |