Class: Google::Apis::GmailV1::History

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb

Overview

A record of a change to the user's mailbox. Each history change may affect multiple messages in multiple ways.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ History

Returns a new instance of History.



628
629
630
# File 'lib/google/apis/gmail_v1/classes.rb', line 628

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idFixnum

The mailbox sequence ID. Corresponds to the JSON property id

Returns:

  • (Fixnum)


599
600
601
# File 'lib/google/apis/gmail_v1/classes.rb', line 599

def id
  @id
end

#labels_addedArray<Google::Apis::GmailV1::HistoryLabelAdded>

Labels added to messages in this history record. Corresponds to the JSON property labelsAdded



604
605
606
# File 'lib/google/apis/gmail_v1/classes.rb', line 604

def labels_added
  @labels_added
end

#labels_removedArray<Google::Apis::GmailV1::HistoryLabelRemoved>

Labels removed from messages in this history record. Corresponds to the JSON property labelsRemoved



609
610
611
# File 'lib/google/apis/gmail_v1/classes.rb', line 609

def labels_removed
  @labels_removed
end

#messagesArray<Google::Apis::GmailV1::Message>

List of messages changed in this history record. The fields for specific change types, such as messagesAdded may duplicate messages in this field. We recommend using the specific change-type fields instead of this. Corresponds to the JSON property messages

Returns:



616
617
618
# File 'lib/google/apis/gmail_v1/classes.rb', line 616

def messages
  @messages
end

#messages_addedArray<Google::Apis::GmailV1::HistoryMessageAdded>

Messages added to the mailbox in this history record. Corresponds to the JSON property messagesAdded



621
622
623
# File 'lib/google/apis/gmail_v1/classes.rb', line 621

def messages_added
  @messages_added
end

#messages_deletedArray<Google::Apis::GmailV1::HistoryMessageDeleted>

Messages deleted (not Trashed) from the mailbox in this history record. Corresponds to the JSON property messagesDeleted



626
627
628
# File 'lib/google/apis/gmail_v1/classes.rb', line 626

def messages_deleted
  @messages_deleted
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



633
634
635
636
637
638
639
640
# File 'lib/google/apis/gmail_v1/classes.rb', line 633

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @labels_added = args[:labels_added] if args.key?(:labels_added)
  @labels_removed = args[:labels_removed] if args.key?(:labels_removed)
  @messages = args[:messages] if args.key?(:messages)
  @messages_added = args[:messages_added] if args.key?(:messages_added)
  @messages_deleted = args[:messages_deleted] if args.key?(:messages_deleted)
end