Class: Google::Apis::GmailV1::KaclsKeyMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb

Overview

Metadata for private keys managed by an external key access control list service. For details about managing key access, see Google Workspace CSE API Reference.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KaclsKeyMetadata

Returns a new instance of KaclsKeyMetadata.



792
793
794
# File 'lib/google/apis/gmail_v1/classes.rb', line 792

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kacls_dataString

Opaque data generated and used by the key access control list service. Maximum size: 8 KiB. Corresponds to the JSON property kaclsData

Returns:

  • (String)


785
786
787
# File 'lib/google/apis/gmail_v1/classes.rb', line 785

def kacls_data
  @kacls_data
end

#kacls_uriString

The URI of the key access control list service that manages the private key. Corresponds to the JSON property kaclsUri

Returns:

  • (String)


790
791
792
# File 'lib/google/apis/gmail_v1/classes.rb', line 790

def kacls_uri
  @kacls_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



797
798
799
800
# File 'lib/google/apis/gmail_v1/classes.rb', line 797

def update!(**args)
  @kacls_data = args[:kacls_data] if args.key?(:kacls_data)
  @kacls_uri = args[:kacls_uri] if args.key?(:kacls_uri)
end