Class: Google::Apis::GmailV1::Label
- Inherits:
-
Object
- Object
- Google::Apis::GmailV1::Label
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb
Overview
Labels are used to categorize messages and threads within the user's mailbox. The maximum number of labels supported for a user's mailbox is 10,000.
Instance Attribute Summary collapse
-
#color ⇒ Google::Apis::GmailV1::LabelColor
The color to assign to the label.
-
#id ⇒ String
The immutable ID of the label.
-
#label_list_visibility ⇒ String
The visibility of the label in the label list in the Gmail web interface.
-
#message_list_visibility ⇒ String
The visibility of messages with this label in the message list in the Gmail web interface.
-
#messages_total ⇒ Fixnum
The total number of messages with the label.
-
#messages_unread ⇒ Fixnum
The number of unread messages with the label.
-
#name ⇒ String
The display name of the label.
-
#threads_total ⇒ Fixnum
The total number of threads with the label.
-
#threads_unread ⇒ Fixnum
The number of unread threads with the label.
-
#type ⇒ String
The owner type for the label.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Label
constructor
A new instance of Label.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Label
Returns a new instance of Label.
885 886 887 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 885 def initialize(**args) update!(**args) end |
Instance Attribute Details
#color ⇒ Google::Apis::GmailV1::LabelColor
The color to assign to the label. Color is only available for labels that have
their type set to user.
Corresponds to the JSON property color
830 831 832 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 830 def color @color end |
#id ⇒ String
The immutable ID of the label.
Corresponds to the JSON property id
835 836 837 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 835 def id @id end |
#label_list_visibility ⇒ String
The visibility of the label in the label list in the Gmail web interface.
Corresponds to the JSON property labelListVisibility
840 841 842 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 840 def label_list_visibility @label_list_visibility end |
#message_list_visibility ⇒ String
The visibility of messages with this label in the message list in the Gmail
web interface.
Corresponds to the JSON property messageListVisibility
846 847 848 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 846 def @message_list_visibility end |
#messages_total ⇒ Fixnum
The total number of messages with the label.
Corresponds to the JSON property messagesTotal
851 852 853 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 851 def @messages_total end |
#messages_unread ⇒ Fixnum
The number of unread messages with the label.
Corresponds to the JSON property messagesUnread
856 857 858 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 856 def @messages_unread end |
#name ⇒ String
The display name of the label.
Corresponds to the JSON property name
861 862 863 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 861 def name @name end |
#threads_total ⇒ Fixnum
The total number of threads with the label.
Corresponds to the JSON property threadsTotal
866 867 868 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 866 def threads_total @threads_total end |
#threads_unread ⇒ Fixnum
The number of unread threads with the label.
Corresponds to the JSON property threadsUnread
871 872 873 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 871 def threads_unread @threads_unread end |
#type ⇒ String
The owner type for the label. User labels are created by the user and can be
modified and deleted by the user and can be applied to any message or thread.
System labels are internally created and cannot be added, modified, or deleted.
System labels may be able to be applied to or removed from messages and
threads under some circumstances but this is not guaranteed. For example,
users can apply and remove the INBOX and UNREAD labels from messages and
threads, but cannot apply or remove the DRAFTS or SENT labels from
messages or threads.
Corresponds to the JSON property type
883 884 885 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 883 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
890 891 892 893 894 895 896 897 898 899 900 901 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 890 def update!(**args) @color = args[:color] if args.key?(:color) @id = args[:id] if args.key?(:id) @label_list_visibility = args[:label_list_visibility] if args.key?(:label_list_visibility) @message_list_visibility = args[:message_list_visibility] if args.key?(:message_list_visibility) @messages_total = args[:messages_total] if args.key?(:messages_total) @messages_unread = args[:messages_unread] if args.key?(:messages_unread) @name = args[:name] if args.key?(:name) @threads_total = args[:threads_total] if args.key?(:threads_total) @threads_unread = args[:threads_unread] if args.key?(:threads_unread) @type = args[:type] if args.key?(:type) end |