Class: Google::Apis::GmailV1::ListCseIdentitiesResponse
- Inherits:
-
Object
- Object
- Google::Apis::GmailV1::ListCseIdentitiesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb
Instance Attribute Summary collapse
-
#cse_identities ⇒ Array<Google::Apis::GmailV1::CseIdentity>
One page of the list of CSE identities configured for the user.
-
#next_page_token ⇒ String
Pagination token to be passed to a subsequent ListCseIdentities call in order to retrieve the next page of identities.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCseIdentitiesResponse
constructor
A new instance of ListCseIdentitiesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCseIdentitiesResponse
Returns a new instance of ListCseIdentitiesResponse.
987 988 989 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 987 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cse_identities ⇒ Array<Google::Apis::GmailV1::CseIdentity>
One page of the list of CSE identities configured for the user.
Corresponds to the JSON property cseIdentities
978 979 980 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 978 def cse_identities @cse_identities end |
#next_page_token ⇒ String
Pagination token to be passed to a subsequent ListCseIdentities call in order
to retrieve the next page of identities. If this value is not returned or is
the empty string, then no further pages remain.
Corresponds to the JSON property nextPageToken
985 986 987 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 985 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
992 993 994 995 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 992 def update!(**args) @cse_identities = args[:cse_identities] if args.key?(:cse_identities) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |