Class: Google::Apis::GmailV1::ListCseKeyPairsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListCseKeyPairsResponse

Returns a new instance of ListCseKeyPairsResponse.



1032
1033
1034
# File 'lib/google/apis/gmail_v1/classes.rb', line 1032

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cse_key_pairsArray<Google::Apis::GmailV1::CseKeyPair>

One page of the list of CSE key pairs installed for the user. Corresponds to the JSON property cseKeyPairs



1023
1024
1025
# File 'lib/google/apis/gmail_v1/classes.rb', line 1023

def cse_key_pairs
  @cse_key_pairs
end

#next_page_tokenString

Pagination token to be passed to a subsequent ListCseKeyPairs call in order to retrieve the next page of key pairs. If this value is not returned, then no further pages remain. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1030
1031
1032
# File 'lib/google/apis/gmail_v1/classes.rb', line 1030

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1037
1038
1039
1040
# File 'lib/google/apis/gmail_v1/classes.rb', line 1037

def update!(**args)
  @cse_key_pairs = args[:cse_key_pairs] if args.key?(:cse_key_pairs)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end