Class: Google::Apis::GmailV1::ListCseKeyPairsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListCseKeyPairsResponse

Returns a new instance of ListCseKeyPairsResponse.



1014
1015
1016
# File 'lib/google/apis/gmail_v1/classes.rb', line 1014

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cse_key_pairsArray<Google::Apis::GmailV1::CseKeyPair>

One page of the list of CSE key pairs installed for the user. Corresponds to the JSON property cseKeyPairs



1005
1006
1007
# File 'lib/google/apis/gmail_v1/classes.rb', line 1005

def cse_key_pairs
  @cse_key_pairs
end

#next_page_tokenString

Pagination token to be passed to a subsequent ListCseKeyPairs call in order to retrieve the next page of key pairs. If this value is not returned, then no further pages remain. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1012
1013
1014
# File 'lib/google/apis/gmail_v1/classes.rb', line 1012

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1019
1020
1021
1022
# File 'lib/google/apis/gmail_v1/classes.rb', line 1019

def update!(**args)
  @cse_key_pairs = args[:cse_key_pairs] if args.key?(:cse_key_pairs)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end