Class: Google::Apis::GmailV1::ListCseKeyPairsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GmailV1::ListCseKeyPairsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb
Instance Attribute Summary collapse
-
#cse_key_pairs ⇒ Array<Google::Apis::GmailV1::CseKeyPair>
One page of the list of CSE key pairs installed for the user.
-
#next_page_token ⇒ String
Pagination token to be passed to a subsequent ListCseKeyPairs call in order to retrieve the next page of key pairs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCseKeyPairsResponse
constructor
A new instance of ListCseKeyPairsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCseKeyPairsResponse
Returns a new instance of ListCseKeyPairsResponse.
1011 1012 1013 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1011 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cse_key_pairs ⇒ Array<Google::Apis::GmailV1::CseKeyPair>
One page of the list of CSE key pairs installed for the user.
Corresponds to the JSON property cseKeyPairs
1002 1003 1004 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1002 def cse_key_pairs @cse_key_pairs end |
#next_page_token ⇒ String
Pagination token to be passed to a subsequent ListCseKeyPairs call in order to
retrieve the next page of key pairs. If this value is not returned, then no
further pages remain.
Corresponds to the JSON property nextPageToken
1009 1010 1011 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1009 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1016 1017 1018 1019 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1016 def update!(**args) @cse_key_pairs = args[:cse_key_pairs] if args.key?(:cse_key_pairs) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |