Class: Google::Apis::GmailV1::Message

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb

Overview

An email message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Message

Returns a new instance of Message.



1344
1345
1346
# File 'lib/google/apis/gmail_v1/classes.rb', line 1344

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#classification_label_valuesArray<Google::Apis::GmailV1::ClassificationLabelValue>

Classification Label values on the message. Available Classification Label schemas can be queried using the Google Drive Labels API. Each classification label ID must be unique. If duplicate IDs are provided, only one will be retained, and the selection is arbitrary. Only used for Google Workspace accounts. Corresponds to the JSON property classificationLabelValues



1285
1286
1287
# File 'lib/google/apis/gmail_v1/classes.rb', line 1285

def classification_label_values
  @classification_label_values
end

#history_idFixnum

The ID of the last history record that modified this message. Corresponds to the JSON property historyId

Returns:

  • (Fixnum)


1290
1291
1292
# File 'lib/google/apis/gmail_v1/classes.rb', line 1290

def history_id
  @history_id
end

#idString

The immutable ID of the message. Corresponds to the JSON property id

Returns:

  • (String)


1295
1296
1297
# File 'lib/google/apis/gmail_v1/classes.rb', line 1295

def id
  @id
end

#internal_dateFixnum

The internal message creation timestamp (epoch ms), which determines ordering in the inbox. For normal SMTP-received email, this represents the time the message was originally accepted by Google, which is more reliable than the Date header. However, for API-migrated mail, it can be configured by client to be based on the Date header. Corresponds to the JSON property internalDate

Returns:

  • (Fixnum)


1304
1305
1306
# File 'lib/google/apis/gmail_v1/classes.rb', line 1304

def internal_date
  @internal_date
end

#label_idsArray<String>

List of IDs of labels applied to this message. Corresponds to the JSON property labelIds

Returns:

  • (Array<String>)


1309
1310
1311
# File 'lib/google/apis/gmail_v1/classes.rb', line 1309

def label_ids
  @label_ids
end

#payloadGoogle::Apis::GmailV1::MessagePart

A single MIME message part. Corresponds to the JSON property payload



1314
1315
1316
# File 'lib/google/apis/gmail_v1/classes.rb', line 1314

def payload
  @payload
end

#rawString

The entire email message in an RFC 2822 formatted and base64url encoded string. Returned in messages.get and drafts.get responses when the format=RAW parameter is supplied. Corresponds to the JSON property raw NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


1322
1323
1324
# File 'lib/google/apis/gmail_v1/classes.rb', line 1322

def raw
  @raw
end

#size_estimateFixnum

Estimated size in bytes of the message. Corresponds to the JSON property sizeEstimate

Returns:

  • (Fixnum)


1327
1328
1329
# File 'lib/google/apis/gmail_v1/classes.rb', line 1327

def size_estimate
  @size_estimate
end

#snippetString

A short part of the message text. Corresponds to the JSON property snippet

Returns:

  • (String)


1332
1333
1334
# File 'lib/google/apis/gmail_v1/classes.rb', line 1332

def snippet
  @snippet
end

#thread_idString

The ID of the thread the message belongs to. To add a message or draft to a thread, the following criteria must be met: 1. The requested threadId must be specified on the Message or Draft.Message you supply with your request.

  1. The References and In-Reply-To headers must be set in compliance with the RFC 2822 standard. 3. The Subject headers must match. Corresponds to the JSON property threadId

Returns:

  • (String)


1342
1343
1344
# File 'lib/google/apis/gmail_v1/classes.rb', line 1342

def thread_id
  @thread_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
# File 'lib/google/apis/gmail_v1/classes.rb', line 1349

def update!(**args)
  @classification_label_values = args[:classification_label_values] if args.key?(:classification_label_values)
  @history_id = args[:history_id] if args.key?(:history_id)
  @id = args[:id] if args.key?(:id)
  @internal_date = args[:internal_date] if args.key?(:internal_date)
  @label_ids = args[:label_ids] if args.key?(:label_ids)
  @payload = args[:payload] if args.key?(:payload)
  @raw = args[:raw] if args.key?(:raw)
  @size_estimate = args[:size_estimate] if args.key?(:size_estimate)
  @snippet = args[:snippet] if args.key?(:snippet)
  @thread_id = args[:thread_id] if args.key?(:thread_id)
end