Class: Google::Apis::GmailV1::MessagePart

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb

Overview

A single MIME message part.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MessagePart

Returns a new instance of MessagePart.



1425
1426
1427
# File 'lib/google/apis/gmail_v1/classes.rb', line 1425

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bodyGoogle::Apis::GmailV1::MessagePartBody

The body of a single MIME message part. Corresponds to the JSON property body



1392
1393
1394
# File 'lib/google/apis/gmail_v1/classes.rb', line 1392

def body
  @body
end

#filenameString

The filename of the attachment. Only present if this message part represents an attachment. Corresponds to the JSON property filename

Returns:

  • (String)


1398
1399
1400
# File 'lib/google/apis/gmail_v1/classes.rb', line 1398

def filename
  @filename
end

#headersArray<Google::Apis::GmailV1::MessagePartHeader>

List of headers on this message part. For the top-level message part, representing the entire message payload, it will contain the standard RFC 2822 email headers such as To, From, and Subject. Corresponds to the JSON property headers



1405
1406
1407
# File 'lib/google/apis/gmail_v1/classes.rb', line 1405

def headers
  @headers
end

#mime_typeString

The MIME type of the message part. Corresponds to the JSON property mimeType

Returns:

  • (String)


1410
1411
1412
# File 'lib/google/apis/gmail_v1/classes.rb', line 1410

def mime_type
  @mime_type
end

#part_idString

The immutable ID of the message part. Corresponds to the JSON property partId

Returns:

  • (String)


1415
1416
1417
# File 'lib/google/apis/gmail_v1/classes.rb', line 1415

def part_id
  @part_id
end

#partsArray<Google::Apis::GmailV1::MessagePart>

The child MIME message parts of this part. This only applies to container MIME message parts, for example multipart/*. For non- container MIME message part types, such as text/plain, this field is empty. For more information, see RFC 1521. Corresponds to the JSON property parts



1423
1424
1425
# File 'lib/google/apis/gmail_v1/classes.rb', line 1423

def parts
  @parts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1430
1431
1432
1433
1434
1435
1436
1437
# File 'lib/google/apis/gmail_v1/classes.rb', line 1430

def update!(**args)
  @body = args[:body] if args.key?(:body)
  @filename = args[:filename] if args.key?(:filename)
  @headers = args[:headers] if args.key?(:headers)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @part_id = args[:part_id] if args.key?(:part_id)
  @parts = args[:parts] if args.key?(:parts)
end