Class: Google::Apis::GmailV1::ModifyMessageRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ModifyMessageRequest

Returns a new instance of ModifyMessageRequest.



1535
1536
1537
# File 'lib/google/apis/gmail_v1/classes.rb', line 1535

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#add_classification_labelsArray<Google::Apis::GmailV1::ClassificationLabelValue>

A list of classification label values to add. If a Classification Label with the same label ID is already applied to the message, fields with existing field IDs will be updated and fields with new field IDs will be added. There's a limit of 20 Classification Label values per request. If the message is already classified and the final total number of Classification Label values exceeds the maximum allowed number of Classification Label values per message, the modification fails. Corresponds to the JSON property addClassificationLabels



1516
1517
1518
# File 'lib/google/apis/gmail_v1/classes.rb', line 1516

def add_classification_labels
  @add_classification_labels
end

#add_label_idsArray<String>

A list of IDs of labels to add to this message. You can add up to 100 labels with each update. Corresponds to the JSON property addLabelIds

Returns:

  • (Array<String>)


1522
1523
1524
# File 'lib/google/apis/gmail_v1/classes.rb', line 1522

def add_label_ids
  @add_label_ids
end

#remove_classification_label_idsArray<String>

A list of Classification Label values to remove from this message. Corresponds to the JSON property removeClassificationLabelIds

Returns:

  • (Array<String>)


1527
1528
1529
# File 'lib/google/apis/gmail_v1/classes.rb', line 1527

def remove_classification_label_ids
  @remove_classification_label_ids
end

#remove_label_idsArray<String>

A list IDs of labels to remove from this message. You can remove up to 100 labels with each update. Corresponds to the JSON property removeLabelIds

Returns:

  • (Array<String>)


1533
1534
1535
# File 'lib/google/apis/gmail_v1/classes.rb', line 1533

def remove_label_ids
  @remove_label_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1540
1541
1542
1543
1544
1545
# File 'lib/google/apis/gmail_v1/classes.rb', line 1540

def update!(**args)
  @add_classification_labels = args[:add_classification_labels] if args.key?(:add_classification_labels)
  @add_label_ids = args[:add_label_ids] if args.key?(:add_label_ids)
  @remove_classification_label_ids = args[:remove_classification_label_ids] if args.key?(:remove_classification_label_ids)
  @remove_label_ids = args[:remove_label_ids] if args.key?(:remove_label_ids)
end