Class: Google::Apis::GmailV1::SendAs

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb

Overview

Settings associated with a send-as alias, which can be either the primary login address associated with the account or a custom "from" address. Send-as aliases correspond to the "Send Mail As" feature in the web interface. The send-as alias must be a valid email address.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SendAs

Returns a new instance of SendAs.



1723
1724
1725
# File 'lib/google/apis/gmail_v1/classes.rb', line 1723

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

A name that appears in the "From:" header for mail sent using this alias. For custom "from" addresses, when this is empty, Gmail will populate the "From:" header with the name that is used for the primary address associated with the account. If the admin has disabled the ability for users to update their name format, requests to update this field for the primary login will silently fail. Corresponds to the JSON property displayName

Returns:

  • (String)


1665
1666
1667
# File 'lib/google/apis/gmail_v1/classes.rb', line 1665

def display_name
  @display_name
end

#is_defaultBoolean Also known as: is_default?

Whether this address is selected as the default "From:" address in situations such as composing a new message or sending a vacation auto-reply. Every Gmail account has exactly one default send-as address, so the only legal value that clients may write to this field is true. Changing this from false to true for an address will result in this field becoming false for the other previous default address. Corresponds to the JSON property isDefault

Returns:

  • (Boolean)


1675
1676
1677
# File 'lib/google/apis/gmail_v1/classes.rb', line 1675

def is_default
  @is_default
end

#is_primaryBoolean Also known as: is_primary?

Whether this address is the primary address used to login to the account. Every Gmail account has exactly one primary address, and it cannot be deleted from the collection of send-as aliases. This field is read-only. Corresponds to the JSON property isPrimary

Returns:

  • (Boolean)


1683
1684
1685
# File 'lib/google/apis/gmail_v1/classes.rb', line 1683

def is_primary
  @is_primary
end

#reply_to_addressString

An optional email address that is included in a "Reply-To:" header for mail sent using this alias. If this is empty, Gmail will not generate a "Reply-To:" header. Corresponds to the JSON property replyToAddress

Returns:

  • (String)


1691
1692
1693
# File 'lib/google/apis/gmail_v1/classes.rb', line 1691

def reply_to_address
  @reply_to_address
end

#send_as_emailString

The email address that appears in the "From:" header for mail sent using this alias. This is read-only for all operations except create. Corresponds to the JSON property sendAsEmail

Returns:

  • (String)


1697
1698
1699
# File 'lib/google/apis/gmail_v1/classes.rb', line 1697

def send_as_email
  @send_as_email
end

#signatureString

An optional HTML signature that is included in messages composed with this alias in the Gmail web UI. This signature is added to new emails only. Corresponds to the JSON property signature

Returns:

  • (String)


1703
1704
1705
# File 'lib/google/apis/gmail_v1/classes.rb', line 1703

def signature
  @signature
end

#smtp_msaGoogle::Apis::GmailV1::SmtpMsa

Configuration for communication with an SMTP service. Corresponds to the JSON property smtpMsa



1708
1709
1710
# File 'lib/google/apis/gmail_v1/classes.rb', line 1708

def smtp_msa
  @smtp_msa
end

#treat_as_aliasBoolean Also known as: treat_as_alias?

Whether Gmail should treat this address as an alias for the user's primary email address. This setting only applies to custom "from" aliases. Corresponds to the JSON property treatAsAlias

Returns:

  • (Boolean)


1714
1715
1716
# File 'lib/google/apis/gmail_v1/classes.rb', line 1714

def treat_as_alias
  @treat_as_alias
end

#verification_statusString

Indicates whether this address has been verified for use as a send-as alias. Read-only. This setting only applies to custom "from" aliases. Corresponds to the JSON property verificationStatus

Returns:

  • (String)


1721
1722
1723
# File 'lib/google/apis/gmail_v1/classes.rb', line 1721

def verification_status
  @verification_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
# File 'lib/google/apis/gmail_v1/classes.rb', line 1728

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @is_default = args[:is_default] if args.key?(:is_default)
  @is_primary = args[:is_primary] if args.key?(:is_primary)
  @reply_to_address = args[:reply_to_address] if args.key?(:reply_to_address)
  @send_as_email = args[:send_as_email] if args.key?(:send_as_email)
  @signature = args[:signature] if args.key?(:signature)
  @smtp_msa = args[:smtp_msa] if args.key?(:smtp_msa)
  @treat_as_alias = args[:treat_as_alias] if args.key?(:treat_as_alias)
  @verification_status = args[:verification_status] if args.key?(:verification_status)
end