Class: Google::Apis::GmailV1::SmimeInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb

Overview

An S/MIME email config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SmimeInfo

Returns a new instance of SmimeInfo.



1814
1815
1816
# File 'lib/google/apis/gmail_v1/classes.rb', line 1814

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encrypted_key_passwordString

Encrypted key password, when key is encrypted. Corresponds to the JSON property encryptedKeyPassword

Returns:

  • (String)


1774
1775
1776
# File 'lib/google/apis/gmail_v1/classes.rb', line 1774

def encrypted_key_password
  @encrypted_key_password
end

#expirationFixnum

When the certificate expires (in milliseconds since epoch). Corresponds to the JSON property expiration

Returns:

  • (Fixnum)


1779
1780
1781
# File 'lib/google/apis/gmail_v1/classes.rb', line 1779

def expiration
  @expiration
end

#idString

The immutable ID for the SmimeInfo. Corresponds to the JSON property id

Returns:

  • (String)


1784
1785
1786
# File 'lib/google/apis/gmail_v1/classes.rb', line 1784

def id
  @id
end

#is_defaultBoolean Also known as: is_default?

Whether this SmimeInfo is the default one for this user's send-as address. Corresponds to the JSON property isDefault

Returns:

  • (Boolean)


1789
1790
1791
# File 'lib/google/apis/gmail_v1/classes.rb', line 1789

def is_default
  @is_default
end

#issuer_cnString

The S/MIME certificate issuer's common name. Corresponds to the JSON property issuerCn

Returns:

  • (String)


1795
1796
1797
# File 'lib/google/apis/gmail_v1/classes.rb', line 1795

def issuer_cn
  @issuer_cn
end

#pemString

PEM formatted X509 concatenated certificate string (standard base64 encoding). Format used for returning key, which includes public key as well as certificate chain (not private key). Corresponds to the JSON property pem

Returns:

  • (String)


1802
1803
1804
# File 'lib/google/apis/gmail_v1/classes.rb', line 1802

def pem
  @pem
end

#pkcs12String

PKCS#12 format containing a single private/public key pair and certificate chain. This format is only accepted from client for creating a new SmimeInfo and is never returned, because the private key is not intended to be exported. PKCS#12 may be encrypted, in which case encryptedKeyPassword should be set appropriately. Corresponds to the JSON property pkcs12 NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


1812
1813
1814
# File 'lib/google/apis/gmail_v1/classes.rb', line 1812

def pkcs12
  @pkcs12
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1819
1820
1821
1822
1823
1824
1825
1826
1827
# File 'lib/google/apis/gmail_v1/classes.rb', line 1819

def update!(**args)
  @encrypted_key_password = args[:encrypted_key_password] if args.key?(:encrypted_key_password)
  @expiration = args[:expiration] if args.key?(:expiration)
  @id = args[:id] if args.key?(:id)
  @is_default = args[:is_default] if args.key?(:is_default)
  @issuer_cn = args[:issuer_cn] if args.key?(:issuer_cn)
  @pem = args[:pem] if args.key?(:pem)
  @pkcs12 = args[:pkcs12] if args.key?(:pkcs12)
end