Class: Google::Apis::GmailV1::SmimeInfo
- Inherits:
-
Object
- Object
- Google::Apis::GmailV1::SmimeInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb
Overview
An S/MIME email config.
Instance Attribute Summary collapse
-
#encrypted_key_password ⇒ String
Encrypted key password, when key is encrypted.
-
#expiration ⇒ Fixnum
When the certificate expires (in milliseconds since epoch).
-
#id ⇒ String
The immutable ID for the SmimeInfo.
-
#is_default ⇒ Boolean
(also: #is_default?)
Whether this SmimeInfo is the default one for this user's send-as address.
-
#issuer_cn ⇒ String
The S/MIME certificate issuer's common name.
-
#pem ⇒ String
PEM formatted X509 concatenated certificate string (standard base64 encoding).
-
#pkcs12 ⇒ String
PKCS#12 format containing a single private/public key pair and certificate chain.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SmimeInfo
constructor
A new instance of SmimeInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SmimeInfo
Returns a new instance of SmimeInfo.
1773 1774 1775 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1773 def initialize(**args) update!(**args) end |
Instance Attribute Details
#encrypted_key_password ⇒ String
Encrypted key password, when key is encrypted.
Corresponds to the JSON property encryptedKeyPassword
1733 1734 1735 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1733 def encrypted_key_password @encrypted_key_password end |
#expiration ⇒ Fixnum
When the certificate expires (in milliseconds since epoch).
Corresponds to the JSON property expiration
1738 1739 1740 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1738 def expiration @expiration end |
#id ⇒ String
The immutable ID for the SmimeInfo.
Corresponds to the JSON property id
1743 1744 1745 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1743 def id @id end |
#is_default ⇒ Boolean Also known as: is_default?
Whether this SmimeInfo is the default one for this user's send-as address.
Corresponds to the JSON property isDefault
1748 1749 1750 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1748 def is_default @is_default end |
#issuer_cn ⇒ String
The S/MIME certificate issuer's common name.
Corresponds to the JSON property issuerCn
1754 1755 1756 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1754 def issuer_cn @issuer_cn end |
#pem ⇒ String
PEM formatted X509 concatenated certificate string (standard base64 encoding).
Format used for returning key, which includes public key as well as
certificate chain (not private key).
Corresponds to the JSON property pem
1761 1762 1763 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1761 def pem @pem end |
#pkcs12 ⇒ String
PKCS#12 format containing a single private/public key pair and certificate
chain. This format is only accepted from client for creating a new SmimeInfo
and is never returned, because the private key is not intended to be exported.
PKCS#12 may be encrypted, in which case encryptedKeyPassword should be set
appropriately.
Corresponds to the JSON property pkcs12
NOTE: Values are automatically base64 encoded/decoded in the client library.
1771 1772 1773 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1771 def pkcs12 @pkcs12 end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1778 1779 1780 1781 1782 1783 1784 1785 1786 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 1778 def update!(**args) @encrypted_key_password = args[:encrypted_key_password] if args.key?(:encrypted_key_password) @expiration = args[:expiration] if args.key?(:expiration) @id = args[:id] if args.key?(:id) @is_default = args[:is_default] if args.key?(:is_default) @issuer_cn = args[:issuer_cn] if args.key?(:issuer_cn) @pem = args[:pem] if args.key?(:pem) @pkcs12 = args[:pkcs12] if args.key?(:pkcs12) end |