Class: Google::Apis::GmailV1::SmimeInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb

Overview

An S/MIME email config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SmimeInfo

Returns a new instance of SmimeInfo.



1772
1773
1774
# File 'lib/google/apis/gmail_v1/classes.rb', line 1772

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encrypted_key_passwordString

Encrypted key password, when key is encrypted. Corresponds to the JSON property encryptedKeyPassword

Returns:

  • (String)


1732
1733
1734
# File 'lib/google/apis/gmail_v1/classes.rb', line 1732

def encrypted_key_password
  @encrypted_key_password
end

#expirationFixnum

When the certificate expires (in milliseconds since epoch). Corresponds to the JSON property expiration

Returns:

  • (Fixnum)


1737
1738
1739
# File 'lib/google/apis/gmail_v1/classes.rb', line 1737

def expiration
  @expiration
end

#idString

The immutable ID for the SmimeInfo. Corresponds to the JSON property id

Returns:

  • (String)


1742
1743
1744
# File 'lib/google/apis/gmail_v1/classes.rb', line 1742

def id
  @id
end

#is_defaultBoolean Also known as: is_default?

Whether this SmimeInfo is the default one for this user's send-as address. Corresponds to the JSON property isDefault

Returns:

  • (Boolean)


1747
1748
1749
# File 'lib/google/apis/gmail_v1/classes.rb', line 1747

def is_default
  @is_default
end

#issuer_cnString

The S/MIME certificate issuer's common name. Corresponds to the JSON property issuerCn

Returns:

  • (String)


1753
1754
1755
# File 'lib/google/apis/gmail_v1/classes.rb', line 1753

def issuer_cn
  @issuer_cn
end

#pemString

PEM formatted X509 concatenated certificate string (standard base64 encoding). Format used for returning key, which includes public key as well as certificate chain (not private key). Corresponds to the JSON property pem

Returns:

  • (String)


1760
1761
1762
# File 'lib/google/apis/gmail_v1/classes.rb', line 1760

def pem
  @pem
end

#pkcs12String

PKCS#12 format containing a single private/public key pair and certificate chain. This format is only accepted from client for creating a new SmimeInfo and is never returned, because the private key is not intended to be exported. PKCS#12 may be encrypted, in which case encryptedKeyPassword should be set appropriately. Corresponds to the JSON property pkcs12 NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


1770
1771
1772
# File 'lib/google/apis/gmail_v1/classes.rb', line 1770

def pkcs12
  @pkcs12
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1777
1778
1779
1780
1781
1782
1783
1784
1785
# File 'lib/google/apis/gmail_v1/classes.rb', line 1777

def update!(**args)
  @encrypted_key_password = args[:encrypted_key_password] if args.key?(:encrypted_key_password)
  @expiration = args[:expiration] if args.key?(:expiration)
  @id = args[:id] if args.key?(:id)
  @is_default = args[:is_default] if args.key?(:is_default)
  @issuer_cn = args[:issuer_cn] if args.key?(:issuer_cn)
  @pem = args[:pem] if args.key?(:pem)
  @pkcs12 = args[:pkcs12] if args.key?(:pkcs12)
end