Class: Google::Apis::GmailV1::SmtpMsa

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb

Overview

Configuration for communication with an SMTP service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SmtpMsa

Returns a new instance of SmtpMsa.



1826
1827
1828
# File 'lib/google/apis/gmail_v1/classes.rb', line 1826

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hostString

The hostname of the SMTP service. Required. Corresponds to the JSON property host

Returns:

  • (String)


1799
1800
1801
# File 'lib/google/apis/gmail_v1/classes.rb', line 1799

def host
  @host
end

#passwordString

The password that will be used for authentication with the SMTP service. This is a write-only field that can be specified in requests to create or update SendAs settings; it is never populated in responses. Corresponds to the JSON property password

Returns:

  • (String)


1806
1807
1808
# File 'lib/google/apis/gmail_v1/classes.rb', line 1806

def password
  @password
end

#portFixnum

The port of the SMTP service. Required. Corresponds to the JSON property port

Returns:

  • (Fixnum)


1811
1812
1813
# File 'lib/google/apis/gmail_v1/classes.rb', line 1811

def port
  @port
end

#security_modeString

The protocol that will be used to secure communication with the SMTP service. Required. Corresponds to the JSON property securityMode

Returns:

  • (String)


1817
1818
1819
# File 'lib/google/apis/gmail_v1/classes.rb', line 1817

def security_mode
  @security_mode
end

#usernameString

The username that will be used for authentication with the SMTP service. This is a write-only field that can be specified in requests to create or update SendAs settings; it is never populated in responses. Corresponds to the JSON property username

Returns:

  • (String)


1824
1825
1826
# File 'lib/google/apis/gmail_v1/classes.rb', line 1824

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1831
1832
1833
1834
1835
1836
1837
# File 'lib/google/apis/gmail_v1/classes.rb', line 1831

def update!(**args)
  @host = args[:host] if args.key?(:host)
  @password = args[:password] if args.key?(:password)
  @port = args[:port] if args.key?(:port)
  @security_mode = args[:security_mode] if args.key?(:security_mode)
  @username = args[:username] if args.key?(:username)
end