Class: Google::Apis::GmailV1::VacationSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb

Overview

Vacation auto-reply settings for an account. These settings correspond to the " Vacation responder" feature in the web interface.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VacationSettings

Returns a new instance of VacationSettings.



1936
1937
1938
# File 'lib/google/apis/gmail_v1/classes.rb', line 1936

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_auto_replyBoolean Also known as: enable_auto_reply?

Flag that controls whether Gmail automatically replies to messages. Corresponds to the JSON property enableAutoReply

Returns:

  • (Boolean)


1882
1883
1884
# File 'lib/google/apis/gmail_v1/classes.rb', line 1882

def enable_auto_reply
  @enable_auto_reply
end

#end_timeFixnum

An optional end time for sending auto-replies (epoch ms). When this is specified, Gmail will automatically reply only to messages that it receives before the end time. If both startTime and endTime are specified, startTime must precede endTime. Corresponds to the JSON property endTime

Returns:

  • (Fixnum)


1891
1892
1893
# File 'lib/google/apis/gmail_v1/classes.rb', line 1891

def end_time
  @end_time
end

#response_body_htmlString

Response body in HTML format. Gmail will sanitize the HTML before storing it. If both response_body_plain_text and response_body_html are specified, response_body_html will be used. Corresponds to the JSON property responseBodyHtml

Returns:

  • (String)


1898
1899
1900
# File 'lib/google/apis/gmail_v1/classes.rb', line 1898

def response_body_html
  @response_body_html
end

#response_body_plain_textString

Response body in plain text format. If both response_body_plain_text and response_body_html are specified, response_body_html will be used. Corresponds to the JSON property responseBodyPlainText

Returns:

  • (String)


1904
1905
1906
# File 'lib/google/apis/gmail_v1/classes.rb', line 1904

def response_body_plain_text
  @response_body_plain_text
end

#response_subjectString

Optional text to prepend to the subject line in vacation responses. In order to enable auto-replies, either the response subject or the response body must be nonempty. Corresponds to the JSON property responseSubject

Returns:

  • (String)


1911
1912
1913
# File 'lib/google/apis/gmail_v1/classes.rb', line 1911

def response_subject
  @response_subject
end

#restrict_to_contactsBoolean Also known as: restrict_to_contacts?

Flag that determines whether responses are sent to recipients who are not in the user's list of contacts. Corresponds to the JSON property restrictToContacts

Returns:

  • (Boolean)


1917
1918
1919
# File 'lib/google/apis/gmail_v1/classes.rb', line 1917

def restrict_to_contacts
  @restrict_to_contacts
end

#restrict_to_domainBoolean Also known as: restrict_to_domain?

Flag that determines whether responses are sent to recipients who are outside of the user's domain. This feature is only available for Google Workspace users. Corresponds to the JSON property restrictToDomain

Returns:

  • (Boolean)


1925
1926
1927
# File 'lib/google/apis/gmail_v1/classes.rb', line 1925

def restrict_to_domain
  @restrict_to_domain
end

#start_timeFixnum

An optional start time for sending auto-replies (epoch ms). When this is specified, Gmail will automatically reply only to messages that it receives after the start time. If both startTime and endTime are specified, startTime must precede endTime. Corresponds to the JSON property startTime

Returns:

  • (Fixnum)


1934
1935
1936
# File 'lib/google/apis/gmail_v1/classes.rb', line 1934

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1941
1942
1943
1944
1945
1946
1947
1948
1949
1950
# File 'lib/google/apis/gmail_v1/classes.rb', line 1941

def update!(**args)
  @enable_auto_reply = args[:enable_auto_reply] if args.key?(:enable_auto_reply)
  @end_time = args[:end_time] if args.key?(:end_time)
  @response_body_html = args[:response_body_html] if args.key?(:response_body_html)
  @response_body_plain_text = args[:response_body_plain_text] if args.key?(:response_body_plain_text)
  @response_subject = args[:response_subject] if args.key?(:response_subject)
  @restrict_to_contacts = args[:restrict_to_contacts] if args.key?(:restrict_to_contacts)
  @restrict_to_domain = args[:restrict_to_domain] if args.key?(:restrict_to_domain)
  @start_time = args[:start_time] if args.key?(:start_time)
end