Class: Google::Apis::GmailV1::WatchResponse
- Inherits:
-
Object
- Object
- Google::Apis::GmailV1::WatchResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb
Overview
Push notification watch response.
Instance Attribute Summary collapse
-
#expiration ⇒ Fixnum
When Gmail will stop sending notifications for mailbox updates (epoch millis).
-
#history_id ⇒ Fixnum
The ID of the mailbox's current history record.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WatchResponse
constructor
A new instance of WatchResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WatchResponse
Returns a new instance of WatchResponse.
2056 2057 2058 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 2056 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expiration ⇒ Fixnum
When Gmail will stop sending notifications for mailbox updates (epoch millis).
Call watch again before this time to renew the watch.
Corresponds to the JSON property expiration
2049 2050 2051 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 2049 def expiration @expiration end |
#history_id ⇒ Fixnum
The ID of the mailbox's current history record.
Corresponds to the JSON property historyId
2054 2055 2056 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 2054 def history_id @history_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2061 2062 2063 2064 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 2061 def update!(**args) @expiration = args[:expiration] if args.key?(:expiration) @history_id = args[:history_id] if args.key?(:history_id) end |