Class: Google::Apis::GmailV1::WatchResponse
- Inherits:
-
Object
- Object
- Google::Apis::GmailV1::WatchResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmail_v1/classes.rb,
lib/google/apis/gmail_v1/representations.rb,
lib/google/apis/gmail_v1/representations.rb
Overview
Push notification watch response.
Instance Attribute Summary collapse
-
#expiration ⇒ Fixnum
When Gmail will stop sending notifications for mailbox updates (epoch millis).
-
#history_id ⇒ Fixnum
The ID of the mailbox's current history record.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WatchResponse
constructor
A new instance of WatchResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WatchResponse
Returns a new instance of WatchResponse.
2015 2016 2017 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 2015 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expiration ⇒ Fixnum
When Gmail will stop sending notifications for mailbox updates (epoch millis).
Call watch again before this time to renew the watch.
Corresponds to the JSON property expiration
2008 2009 2010 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 2008 def expiration @expiration end |
#history_id ⇒ Fixnum
The ID of the mailbox's current history record.
Corresponds to the JSON property historyId
2013 2014 2015 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 2013 def history_id @history_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2020 2021 2022 2023 |
# File 'lib/google/apis/gmail_v1/classes.rb', line 2020 def update!(**args) @expiration = args[:expiration] if args.key?(:expiration) @history_id = args[:history_id] if args.key?(:history_id) end |